/** 
 *   Equatorial to horizon coordinates
 *
 *   (c) Copyright 2005 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

/**
 * Given:
 *  ha      hour angle
 *  dec     declination
 *  phi     observatory latitude
 *
 * Returned:
 *  az      azimuth
 *  el      elevation
 *
 * Notes:
 *
 * 1) All the arguments are angles in radians.
 *
 * 2) Azimuth is returned in the range 0-2pi; north is zero, and east
 * is +pi/2.  Elevation is returned in the range +/-pi/2.
 *
 * 3) The latitude must be geodetic.  In critical applications,
 * corrections for polar motion should be applied.
 **/

#include <math.h>

#define PI 3.1415926535897932384626433832795
#define TWOPI 6.283185307179586476925286766559

int equ2hor(double ha, double dec, double phi, double *az, double *el)
{
    double a, r, x, y, z;
    double cd, ch, cp, sd, sh, sp;

    sh = sin(ha);
    ch = cos(ha);
    sd = sin(dec);
    cd = cos(dec);
    sp = sin(phi);
    cp = cos(phi);

/*  az, el as x,y,z */
    x = -ch * cd * sp + sd * cp;
    y = -sh * cd;
    z =  ch * cd * cp + sd * sp;

/*  To spherical */
    r = sqrt(x * x + y * y);
    if (r == 0.) {
        a = 0.;
    } else {
	a = atan2(y, x);
    }
    if (a < 0.) {
	a += TWOPI;
    }
    *az = a;
    *el = atan2(z, r);

    return 0;
} 

